@@ -30,30 +30,20 @@
 ## @item "FeatureType'
 ## This option (a mere "f" suffices) can be one of:
 ## @table @asis
-## @item
-## "WayPoint or simply "w": Read waypoints.
-## @end item
+## @item "WayPoint or simply "w": Read waypoints.
 ##
-## @item
-## "Track" or "t": read tracks.
-## @end item
+## @item "Track" or "t": read tracks.
 ##
-## @item
-## "Route" or "t": read routes.
-## @end item
+## @item "Route" or "t": read routes.
 ##
-## @item
-## "Auto" or "a" (default value): read all data.
-## @end item
+## @item "Auto" or "a" (default value): read all data.
 ## @end table
 ##
 ## Multiple FeatureType property/value pairs can be specified.
-## @end item
 ##
 ## @item "Index"
 ## The ensuing Index value should be a numeric value, or numeric vector,
 ## of indices of the features to be read.  Works currently only for waypoints.
-## @end item
 ## @end itemize
 ##
 ## Output argument @var{out} is a struct array with field names Name,
