@@ -1,4 +1,4 @@
-## Copyright (C) 2014-2020 Philip Nienhuis
+## Copyright (C) 2014-2022 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
@@ -103,8 +103,8 @@ function [status] = shapewrite (shp, fname="", atts=[])
 
   ## Check for dbfwrite function
   if (isempty (which ("dbfwrite")))
-    error ("shapewrite: dbfwrite function not found. (io package installed \
-and loaded?)");
+    error (["shapewrite: dbfwrite function not found. (io package ", ...
+            "installed and loaded?)"]);
     return;
   endif
 
@@ -128,8 +128,8 @@ and loaded?)");
   if (nargin > 2)
     if (isstruct (atts))
       if (! n_dbfspec)
-        warning ("shapewrite: DbfSpec not implemented; including requested \
-attributes\n");
+        warning (["shapewrite: DbfSpec not implemented; including ", ...
+                  "requested attributes\n"]);
         n_dbfspec = 1;
       endif
       ## Get attribute names from field "FieldName"; allow lowercase and camelcase
@@ -139,11 +139,12 @@ attributes\n");
         ## Get fieldnames out of first match
         atts = {atts.(fieldnames (atts (fnidx)){1})};
       else
-        warning ("shapewrite: no field 'fieldname' (case-insensitive) found \
-in struct\n=> input arg. #3 ignored");
+        warning (["shapewrite: no field 'fieldname' (case-insensitive) ", ...
+                  "found in struct\n=> input arg. #3 ignored"]);
       endif
     elseif (! iscellstr (atts) && ! ischar (atts))
-      error ("shapewrite: arg.#3: attribute name or cellstr array of attribute names expected");
+      error (["shapewrite: arg.#3: attribute name or cellstr array of ", ...
+              "attribute names expected"]);
     endif
     ## Check if requested attributes exist at all in shapestruct
     atts = unique (atts);
@@ -257,7 +258,7 @@ in struct\n=> input arg. #3 ignored");
       ## Nr. of vertices
       npt = numel (shp(ishp).X);
       ## Pointers to parts
-      nptr = idx(1:end-1) .- [0:numel(idx)-2];
+      nptr = idx(1:end-1) - [0:numel(idx)-2];
 
       ## Write record contents
       switch (stype)
